#!/bin/sh
cp ordr3.sqlite pre-1.3.0-ordr3.sqlite
cat <<EOF | sqlite3 ordr3.sqlite

CREATE TABLE
  orders_1_3_0 (
    id INTEGER NOT NULL,
    cas_description TEXT NOT NULL,
    catalog_nr TEXT NOT NULL,
    vendor TEXT NOT NULL,
    category VARCHAR(10) NOT NULL,
    package_size TEXT NOT NULL,
    unit_price FLOAT NOT NULL,
    currency TEXT NOT NULL,
    amount INTEGER NOT NULL,
    account TEXT NOT NULL,
    comment TEXT NOT NULL,
    created_on DATETIME NOT NULL,
    created_by TEXT,
    status VARCHAR(9),
    CONSTRAINT pk_orders PRIMARY KEY (id),
    CONSTRAINT ck_orders_ordercategory CHECK (
      category IN (
        'DISPOSABLE',
        'SOLVENT',
        'CHEMICAL',
        'BIOLAB',
        'SYNTHESIS'
      )
    ),
    CONSTRAINT ck_orders_orderstatus CHECK (
      status IN (
        'OPEN',
        'FUNDED',
        'APPROVAL',
        'ORDERED',
        'COMPLETED',
        'HOLD'
      )
    )
  );

INSERT INTO orders_1_3_0 (
  	id,
    cas_description,
    catalog_nr,
    vendor,
    category,
    package_size,
    unit_price,
    currency,
    amount,
    account,
    comment,
    created_on,
    created_by,
    status)
  SELECT 
  	id,
    cas_description,
    catalog_nr,
    vendor,
    category,
    package_size,
    unit_price,
    currency,
    amount,
    account,
    comment,
    created_on,
    created_by,
    status
FROM orders;

DROP TABLE orders;
ALTER TABLE orders_1_3_0 RENAME TO orders;

CREATE TABLE
  logs_1_3_0 (
    order_id INTEGER NOT NULL,
    status VARCHAR(9) NOT NULL,
    date DATETIME NOT NULL,
    "by" TEXT NOT NULL,
    CONSTRAINT pk_logs PRIMARY KEY (order_id, status, date),
    CONSTRAINT fk_logs_order_id_orders FOREIGN KEY (order_id) REFERENCES orders (id),
    CONSTRAINT ck_logs_orderstatus CHECK (
      status IN (
        'OPEN',
        'FUNDED',
        'APPROVAL',
        'ORDERED',
        'COMPLETED',
        'HOLD'
      )
    )
  );

INSERT INTO logs_1_3_0 (
  	order_id,
    status,
    date,
    "by"
    )
  SELECT 
    order_id,
    status,
    date,
    "by"
  FROM logs;

DROP TABLE logs;
ALTER TABLE logs_1_3_0 RENAME TO logs;

EOF