import pytest


@pytest.mark.functional
def test_login_ok(testapp):
    response = testapp.get("/", status=302).follow()
    assert "Please Log In" in response

    form = response.form
    form["username"] = "TestAdmin"
    form["password"] = "jane"  # noqa: S105
    response = form.submit("submit").follow()
    assert "My Orders" in response


@pytest.mark.functional
def test_login_wrong_username(testapp):
    response = testapp.get("/", status=302).follow()
    assert "Please Log In" in response

    form = response.form
    form["username"] = "XXAdmin"
    form["password"] = "jane"  # noqa: S105
    response = form.submit("Log In")
    assert "Credentials are invalid" in response


@pytest.mark.functional
def test_login_wrong_password(testapp):
    response = testapp.get("/", status=302).follow()
    assert "Please Log In" in response

    form = response.form
    form["username"] = "TestAdmin"
    form["password"] = "wrong password"  # noqa: S105
    response = form.submit("Log In")
    assert "Credentials are invalid" in response


@pytest.mark.functional
def test_login_fails_inactive_user(testapp):
    response = testapp.get("/", status=302).follow()
    assert "Please Log In" in response

    form = response.form
    form["username"] = "TestInactive"
    form["password"] = "peter"  # noqa: S105
    response = form.submit("Log In")
    assert "Credentials are invalid" in response


@pytest.mark.functional
def test_logout(testapp):
    response = testapp.get("/", status=302).follow()
    assert "Please Log In" in response

    form = response.form
    form["username"] = "TestAdmin"
    form["password"] = "jane"  # noqa: S105
    response = form.submit("submit").follow()
    assert "My Orders" in response

    response = testapp.get("/logout", status=302).follow()
    assert "Please Log In" in response


@pytest.mark.functional
def test_breached_faq(testapp):
    response = testapp.get("/breached")
    assert "haveibeenpwned" in response
